==> jc-1.4.0.tar.gz: soot/tagkit/StringConstantValueTag.c <==
// public class soot.tagkit.StringConstantValueTag

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 4919fee97003ed79 soot_coffi_CONSTANT__5fUtf8__5finfo
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class ba90f218e62b80e1 soot_tagkit_StringConstantValueTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_coffi_CONSTANT__5fUtf8__5finfo
// @dep_header soot_tagkit_StringConstantValueTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/coffi/CONSTANT__5fUtf8__5finfo.h"
#include "soot/tagkit/StringConstantValueTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final java.lang.String value
static _jc_field _jc_soot_tagkit_StringConstantValueTag$field_info$value = {
	.name=		"value",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_tagkit_StringConstantValueTag$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_tagkit_StringConstantValueTag$object, refs[-1].soot_tagkit_StringConstantValueTag.value),
};

// Fields
static _jc_field *const _jc_soot_tagkit_StringConstantValueTag$fields[] = {
	&_jc_soot_tagkit_StringConstantValueTag$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_soot_tagkit_StringConstantValueTag$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_soot_tagkit_StringConstantValueTag$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_soot_tagkit_StringConstantValueTag$type,
	.param_types=		&_jc_soot_tagkit_StringConstantValueTag$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_StringConstantValueTag$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_soot_tagkit_StringConstantValueTag$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StringConstantValueTag, _init$c31b894660454d13);

void
_jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13(_jc_env *const env, _jc_soot_tagkit_StringConstantValueTag$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_soot_tagkit_StringConstantValueTag$object *r0;
	struct _jc_java_lang_String$object *r1;
	_jc_byte_array *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(35);				// 0
	_JC_REF_FIELD(env, r0, soot_tagkit_StringConstantValueTag, value) = r1;
	_JC_LINE_NUMBER(36);				// 1
	r2 = _JC_INVOKE_STATIC(env, soot_coffi_CONSTANT__5fUtf8__5finfo, toUtf8$b4af7e1b1eef0b20, 0, r1);
	_JC_REF_FIELD(env, r0, soot_tagkit_ConstantValueTag, bytes) = r2;
	_JC_LINE_NUMBER(37);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getStringValue()
//

static _jc_linenum _jc_soot_tagkit_StringConstantValueTag$linenum_table$getStringValue$3b6fd4874b831061[];

static const unsigned char _jc_soot_tagkit_StringConstantValueTag$param_ptypes$getStringValue$3b6fd4874b831061[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061 = {
	.name=			"getStringValue",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_StringConstantValueTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_StringConstantValueTag$param_ptypes$getStringValue$3b6fd4874b831061,
	.signature_hash=	_JC_JLONG(0x3b6fd4874b831061),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_StringConstantValueTag$vtable, soot_tagkit_StringConstantValueTag.getStringValue$3b6fd4874b831061) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StringConstantValueTag$linenum_table$getStringValue$3b6fd4874b831061
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StringConstantValueTag, getStringValue$3b6fd4874b831061);

_jc_java_lang_String$object *
_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061(_jc_env *const env, _jc_soot_tagkit_StringConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_StringConstantValueTag$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(40);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_tagkit_StringConstantValueTag, value);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_StringConstantValueTag$methods[] = {
	&_jc_soot_tagkit_StringConstantValueTag$method_info$_init$c31b894660454d13,
	&_jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_2[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_41[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_StringConstantValueTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_StringConstantValueTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_97[] = {
	&_jc_soot_tagkit_StringConstantValueTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_110[] = {
	&_jc_soot_tagkit_ConstantValueTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_58,
	[97]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_97,
	[110]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_110,
	[113]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_StringConstantValueTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/coffi/CONSTANT_Utf8_info",	_JC_JLONG(0x4919fee97003ed79) },
	{ "soot/tagkit/ConstantValueTag",	_JC_JLONG(0x927f75e1f2873cee) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_StringConstantValueTag$vtype _jc_soot_tagkit_StringConstantValueTag$type = {
    .type= {
	.name=			"soot/tagkit/StringConstantValueTag",
	.superclass=		&_jc_soot_tagkit_ConstantValueTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_StringConstantValueTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xba90f218e62b80e1),
		.source_file=		"StringConstantValueTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_StringConstantValueTag$refs) + sizeof(_jc_soot_tagkit_StringConstantValueTag$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_soot_tagkit_StringConstantValueTag$fields) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$fields),
		.fields=		_jc_soot_tagkit_StringConstantValueTag$fields,
		.num_methods=		sizeof(_jc_soot_tagkit_StringConstantValueTag$methods) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$methods),
		.methods=		_jc_soot_tagkit_StringConstantValueTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_StringConstantValueTag$class_depends) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$class_depends),
		.class_depends=		_jc_soot_tagkit_StringConstantValueTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_ConstantValueTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	},
	.soot_tagkit_StringConstantValueTag= {
	    .getStringValue$3b6fd4874b831061=
		&_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/tagkit/StringConstantValueTag.c <==
// public class soot.tagkit.StringConstantValueTag

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 4919fee97003ed79 soot_coffi_CONSTANT__5fUtf8__5finfo
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class ba90f218e62b80e1 soot_tagkit_StringConstantValueTag
// @dep_class 145f73eb6621ab3a soot_tagkit_Tag

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_coffi_CONSTANT__5fUtf8__5finfo
// @dep_header soot_tagkit_StringConstantValueTag
// @dep_header soot_tagkit_Tag

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/coffi/CONSTANT__5fUtf8__5finfo.h"
#include "soot/tagkit/StringConstantValueTag.h"
#include "soot/tagkit/Tag.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final java.lang.String value
static _jc_field _jc_soot_tagkit_StringConstantValueTag$field_info$value = {
	.name=		"value",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_tagkit_StringConstantValueTag$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_tagkit_StringConstantValueTag$object, refs[-1].soot_tagkit_StringConstantValueTag.value),
};

// Fields
static _jc_field *const _jc_soot_tagkit_StringConstantValueTag$fields[] = {
	&_jc_soot_tagkit_StringConstantValueTag$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_soot_tagkit_StringConstantValueTag$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_soot_tagkit_StringConstantValueTag$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_soot_tagkit_StringConstantValueTag$type,
	.param_types=		&_jc_soot_tagkit_StringConstantValueTag$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_tagkit_StringConstantValueTag$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_soot_tagkit_StringConstantValueTag$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StringConstantValueTag, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_soot_tagkit_StringConstantValueTag$method$_init$c31b894660454d13(_jc_env *const env, _jc_soot_tagkit_StringConstantValueTag$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_soot_tagkit_StringConstantValueTag$object *r0;
	struct _jc_java_lang_String$object *r1;
	_jc_byte_array *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(35);				// 0
	_JC_REF_FIELD(env, r0, soot_tagkit_StringConstantValueTag, value) = r1;
	_JC_LINE_NUMBER(36);				// 1
	r2 = _JC_INVOKE_STATIC(env, soot_coffi_CONSTANT__5fUtf8__5finfo, toUtf8$b4af7e1b1eef0b20, 0, r1);
	_JC_REF_FIELD(env, r0, soot_tagkit_ConstantValueTag, bytes) = r2;
	_JC_LINE_NUMBER(37);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String getStringValue()
//

static _jc_linenum _jc_soot_tagkit_StringConstantValueTag$linenum_table$getStringValue$3b6fd4874b831061[];

static const unsigned char _jc_soot_tagkit_StringConstantValueTag$param_ptypes$getStringValue$3b6fd4874b831061[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061 = {
	.name=			"getStringValue",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_tagkit_StringConstantValueTag$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_tagkit_StringConstantValueTag$param_ptypes$getStringValue$3b6fd4874b831061,
	.signature_hash=	_JC_JLONG(0x3b6fd4874b831061),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_tagkit_StringConstantValueTag$vtable, soot_tagkit_StringConstantValueTag.getStringValue$3b6fd4874b831061) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_tagkit_StringConstantValueTag$linenum_table$getStringValue$3b6fd4874b831061
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_tagkit_StringConstantValueTag, getStringValue$3b6fd4874b831061);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061(_jc_env *const env, _jc_soot_tagkit_StringConstantValueTag$object *this)
{
	struct _jc_soot_tagkit_StringConstantValueTag$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(40);				// 0
	r1 = _JC_REF_FIELD(env, r0, soot_tagkit_StringConstantValueTag, value);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_tagkit_StringConstantValueTag$methods[] = {
	&_jc_soot_tagkit_StringConstantValueTag$method_info$_init$c31b894660454d13,
	&_jc_soot_tagkit_StringConstantValueTag$method_info$getStringValue$3b6fd4874b831061
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_2[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$getName$bec186f2ce7e1882,
	_JC_NULL
};
static _jc_method *_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_41[] = {
	&_jc_soot_tagkit_ConstantValueTag$method_info$getValue$824c7561d2f47329,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_tagkit_StringConstantValueTag$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_2,
	[41]=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_bucket_41
};

// Interface "quick" lookup hash table
static const void *_jc_soot_tagkit_StringConstantValueTag$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[2]=	&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	[41]=	&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_58[] = {
	&_jc_soot_tagkit_Tag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_97[] = {
	&_jc_soot_tagkit_StringConstantValueTag$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_110[] = {
	&_jc_soot_tagkit_ConstantValueTag$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_tagkit_StringConstantValueTag$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_58,
	[97]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_97,
	[101]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_101,
	[110]=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_bucket_110
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_tagkit_StringConstantValueTag$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/coffi/CONSTANT_Utf8_info",	_JC_JLONG(0x4919fee97003ed79) },
	{ "soot/tagkit/ConstantValueTag",	_JC_JLONG(0x927f75e1f2873cee) },
	{ "soot/tagkit/Tag",	_JC_JLONG(0x145f73eb6621ab3a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_tagkit_StringConstantValueTag$vtype _jc_soot_tagkit_StringConstantValueTag$type = {
    .type= {
	.name=			"soot/tagkit/StringConstantValueTag",
	.superclass=		&_jc_soot_tagkit_ConstantValueTag$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_tagkit_StringConstantValueTag$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_tagkit_StringConstantValueTag$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xba90f218e62b80e1),
		.source_file=		"StringConstantValueTag.java",
		.instance_size=		sizeof(_jc_soot_tagkit_StringConstantValueTag$refs) + sizeof(_jc_soot_tagkit_StringConstantValueTag$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_soot_tagkit_StringConstantValueTag$fields) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$fields),
		.fields=		_jc_soot_tagkit_StringConstantValueTag$fields,
		.num_methods=		sizeof(_jc_soot_tagkit_StringConstantValueTag$methods) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$methods),
		.methods=		_jc_soot_tagkit_StringConstantValueTag$methods,
		.instanceof_hash_table=	_jc_soot_tagkit_StringConstantValueTag$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_tagkit_StringConstantValueTag$class_depends) / sizeof(*_jc_soot_tagkit_StringConstantValueTag$class_depends),
		.class_depends=		_jc_soot_tagkit_StringConstantValueTag$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_tagkit_ConstantValueTag= {
	    .getName$bec186f2ce7e1882=
		&_jc_soot_tagkit_ConstantValueTag$method$getName$bec186f2ce7e1882,
	    .getValue$824c7561d2f47329=
		&_jc_soot_tagkit_ConstantValueTag$method$getValue$824c7561d2f47329,
	},
	.soot_tagkit_StringConstantValueTag= {
	    .getStringValue$3b6fd4874b831061=
		&_jc_soot_tagkit_StringConstantValueTag$method$getStringValue$3b6fd4874b831061,
	},
    }
};
